#
# Copyright (c) 2018 Duo Security
# All Rights Reserved
#
import string

from check import main
from check import http_proxy
from check import radius_server
from check import radius_client
from check import ad_client
from check import ldap_server_auto
from connectivity_results import SKIPPED_SECTION_RESULT, INVALID_SECTION_RESULT


def skipping_tester(config, toolbox):
    return SKIPPED_SECTION_RESULT


def invalid_section_tester(config, toolbox):
    return INVALID_SECTION_RESULT


SECTION_TESTERS = {
    'main': main.check_main,
    'cloud': skipping_tester,
    'duo_only_client': skipping_tester,
    'http_proxy': http_proxy.check_http_proxy,
    'ad_client': ad_client.check_ad_client,
    'radius_client': radius_client.check_radius_client,
    'radius_server_auto': radius_server.check_radius_server,
    'radius_server_iframe': radius_server.check_radius_server,
    'radius_server_challenge': radius_server.check_radius_server,
    'radius_server_concat': radius_server.check_radius_server,
    'radius_server_duo_only': radius_server.check_radius_server,
    'radius_server_eap': radius_server.check_radius_server,
    'ldap_server_auto': ldap_server_auto.check_ldap_server_auto,
}


class SectionTesterResolver(object):
    """
    Class that provides a way to find a tester function for a given auth proxy configuration section name
    """

    def find_tester(self, section_name):
        """
        Determine the testing function to use for the given configuration section name

        Args:
            section_name (string): The name to resolve

        Returns:
            function: The testing function to use for testing the specified section

        """
        section_type = section_name.lower().rstrip(string.digits)

        # Unrecognized sections return appropriate warning
        if section_type in SECTION_TESTERS:
            return SECTION_TESTERS[section_type]
        else:
            return invalid_section_tester


STANDARD_RESOLVER = SectionTesterResolver()
