#
# Copyright (c) 2011 Duo Security
# All Rights Reserved
#

from distutils.core import setup
import platform
import duoauthproxy

metadata = dict(
    name="duoauthproxy",
    version=duoauthproxy.__version__,
    company_name="Duo Security",
    copyright="Copyright Duo Security 2010-2011. All rights reserved.",
    )

if platform.system() == 'Windows':
    import py2exe

    class Target:
        def __init__(self, **kw):
            self.__dict__.update(kw)

    auth_proxy_service = Target(
        description="Duo Authentication Proxy Service",
        modules=['duoauthproxy.proxy_svc'],
        cmdline_style='pywin32',
        **metadata
        )

    # Py2exe attempts to include all these dlls for psutil when it doesn't need to and in fact causes errors
    system_dlls_to_exclude = [
        'API-MS-Win-Core-Handle-L1-1-0.dll',
        'WINNSI.DLL',
        'API-MS-Win-Core-File-L1-1-0.dll',
        'API-MS-Win-Core-Interlocked-L1-1-0.dll',
        'API-MS-Win-Core-IO-L1-1-0.dll',
        'NSI.dll',
        'WTSAPI32.dll',
        'API-MS-Win-Core-LibraryLoader-L1-1-0.dll',
        'API-MS-Win-Core-Misc-L1-1-0.dll',
        'API-MS-Win-Core-ThreadPool-L1-1-0.dll',
        'IPHLPAPI.DLL',
        'MPR.dll',
        'API-MS-Win-Core-LocalRegistry-L1-1-0.dll',
        'API-MS-Win-Core-Profile-L1-1-0.dll',
        'API-MS-Win-Core-ErrorHandling-L1-1-0.dll',
        'API-MS-Win-Core-SysInfo-L1-1-0.dll',
        'API-MS-Win-Core-DelayLoad-L1-1-0.dll',
        'API-MS-Win-Core-Synch-L1-1-0.dll',
        'API-MS-Win-Core-Heap-L1-1-0.dll',
        'API-MS-Win-Security-Base-L1-1-0.dll',
        'API-MS-Win-Core-ProcessThreads-L1-1-0.dll',
        'API-MS-Win-Core-String-L1-1-0.dll',
        "PSAPI.DLL",
        "mswsock.dll",
        "powrprof.dll",
    ]

    setup(
        options={'py2exe': {'dll_excludes': system_dlls_to_exclude}},
        console=['scripts/authproxy', 'scripts/authproxy_passwd', 'scripts/authproxy_connectivity_tool'],
        service=[auth_proxy_service]
        )
else:
    setup(
        packages=['duoauthproxy',
                  'duoauthproxy.modules',
                  'duoauthproxy.lib',
                  'duoauthproxy.lib.drpc',
                  'duoauthproxy.lib.ldap',
                  'duoauthproxy.lib.radius',
                  'duoauthproxy.lib.protect',
                  'duoauthproxy.lib.connectivity',
                  'duoauthproxy.lib.connectivity.check',
                  'duoauthproxy.lib.connectivity.connect',
        ],
        scripts=['scripts/authproxy',
                 'scripts/authproxyctl',
                 'scripts/authproxy_connectivity_tool'],
        **metadata
        )
