#
# Copyright (c) 2018 Duo Security
# All Rights Reserved
#
from base import TestCase

from duoauthproxy.lib.connectivity import connectivity_test_resolver
from duoauthproxy.lib.connectivity.check import http_proxy
from duoauthproxy.lib.connectivity.check import radius_server


class TestConnectivityTestResolver(TestCase):

    def setUp(self):
        super(TestConnectivityTestResolver, self).setUp()

        self.RESOLVER = connectivity_test_resolver.SectionTesterResolver()

    def test_finds_section_tester_exact_match(self):
        actual_result = self.RESOLVER.find_tester('http_proxy')

        self.assertEqual(actual_result, http_proxy.check_http_proxy)

    def test_finds_section_tester_with_number(self):
        actual_result = self.RESOLVER.find_tester('radius_server_auto1')

        self.assertEqual(actual_result, radius_server.check_radius_server)

    def test_no_tester_implemented(self):
        """Test a valid section name but not connectivity tests will be run for it"""
        actual_result = self.RESOLVER.find_tester('duo_only_client')

        self.assertEqual(actual_result, connectivity_test_resolver.skipping_tester)

    def test_invalid_section(self):
        """Test a section name that is not valid"""
        actual_result = self.RESOLVER.find_tester('not_a_section')

        self.assertEqual(actual_result, connectivity_test_resolver.invalid_section_tester)
