#
# Copyright (c) 2013 Duo Security
# All Rights Reserved
#

from twisted.internet import defer
from twisted.trial.unittest import TestCase

import duoauthproxy.modules.duo_only_client
from duoauthproxy.lib.config_provider import ConfigDict


class TestModuleDuoOnlyClient(TestCase):
    def setUp(self):
        self.username = 'someuser'
        self.password = 'somePassword!'
        self.config_items = {
            'username': self.username,
            'password': self.password,
        }
        config = ConfigDict(self.config_items)
        self.instance = duoauthproxy.modules.duo_only_client.Module(config)

    def tearDown(self):
        self.instance.stopService()

    @defer.inlineCallbacks
    def test_basic(self):
        @defer.inlineCallbacks
        def test1(username, password, expect_success):
            res = yield self.instance.authenticate(username,
                                                   password,
                                                   '10.2.68.17')
            self.assertEqual(res.success,
                             expect_success)

        # make sure it ignores primary credentials
        yield test1(
            self.username,
            self.password,
            True
        )
        yield test1(
            self.username + ' not',
            self.password,
            True
        )
        yield test1(
            self.username,
            self.password + ' not',
            True
        )
        yield test1(
            self.username + ' not',
            self.password + ' not',
            True
        )
