#
# Copyright (c) 2011 Duo Security
# All Rights Reserved
#

from twisted.trial.unittest import TestCase

from duoauthproxy.lib.ntlm import *


class TestNTLM(TestCase):
    def test_msnlmp(self):
        """Test data from [MS-NLMP] specification"""
        User = 'User'
        Domain = 'Domain'
        Password = 'Password'
        Time = 0
        ClientChallenge = 'aa'.decode('hex') * 8
        ServerChallenge = '0123456789abcdef'.decode('hex')

        rkey_lmv1 = LMOWFv1(Password, User, Domain)
        rkey_ntv1 = NTOWFv1(Password, User, Domain)
        self.assertEqual(rkey_lmv1,
                         'e52cac67419a9a224a3b108f3fa6cb6d'.decode('hex'))
        self.assertEqual(rkey_ntv1,
                         'a4f49c406510bdcab6824ee7c30fd852'.decode('hex'))

        rsp = ComputeResponse_v1(0, rkey_ntv1, rkey_lmv1,
                                 ServerChallenge, ClientChallenge,
                                 Time, None)
        expected = [
            '98def7b87f88aa5dafe2df779688a172def11c7d5ccdef13'.decode('hex'),
            '67c43011f30298a2ad35ece64f16331c44bdbed927841f94'.decode('hex')
        ]
        self.assertEqual(rsp[0], expected[0])
        self.assertEqual(rsp[1], expected[1])

        rsp = ComputeResponse_v1(NTLMSSP_NEGOTIATE_EXTENDED_SESSIONSECURITY,
                                 rkey_ntv1, rkey_lmv1, ServerChallenge,
                                 ClientChallenge, Time, None)
        expected = [
            'aaaaaaaaaaaaaaaa00000000000000000000000000000000'.decode('hex'),
            '7537f803ae367128ca458204bde7caf81e97ed2683267232'.decode('hex'),
            'd87262b0cde4b1cb7499becccdf10784'.decode('hex')
        ]
        self.assertEqual(rsp[0], expected[0])
        self.assertEqual(rsp[1], expected[1])
        self.assertEqual(rsp[2], expected[2])

        challenge_msg_v2 = ("4e544c4d53535000020000000c000c00"
                            "3800000033828ae20123456789abcdef"
                            "00000000000000002400240044000000"
                            "060070170000000f5300650072007600"
                            "6500720002000c0044006f006d006100"
                            "69006e0001000c005300650072007600"
                            "6500720000000000").decode('hex')
        parsed_challenge_v2 = ChallengeMessage(challenge_msg_v2)

        auth_msg_v2 = ("4e544c4d535350000300000018001800"
                       "6c00000054005400840000000c000c00"
                       "48000000080008005400000010001000"
                       "5c00000010001000d8000000358288e2"
                       "0501280a0000000f44006f006d006100"
                       "69006e00550073006500720043004f00"
                       "4d005000550054004500520086c35097"
                       "ac9cec102554764a57cccc19aaaaaaaa"
                       "aaaaaaaa68cd0ab851e51c96aabc927b"
                       "ebef6a1c010100000000000000000000"
                       "00000000aaaaaaaaaaaaaaaa00000000"
                       "02000c0044006f006d00610069006e00"
                       "01000c00530065007200760065007200"
                       "0000000000000000c5dad2544fc97990"
                       "94ce1ce90bc9d03e").decode('hex')
        AuthenticateMessage(auth_msg_v2)

        rkey_lmv2 = rkey_ntv2 = NTOWFv2(Password, User, Domain)
        self.assertEqual(rkey_lmv2,
                         '0c868a403bfd7a93a3001ef22ef02e3f'.decode('hex'))
        rsp = ComputeResponse_v2(0, rkey_ntv2, rkey_lmv2,
                                 ServerChallenge, ClientChallenge,
                                 Time, parsed_challenge_v2.TargetInfo)
        expected = [
            '86c35097ac9cec102554764a57cccc19aaaaaaaaaaaaaaaa'.decode('hex'),
            ('68cd0ab851e51c96aabc927bebef6a1c'
             '01010000000000000000000000000000'
             'aaaaaaaaaaaaaaaa0000000002000c00'
             '44006f006d00610069006e0001000c00'
             '53006500720076006500720000000000'
             '00000000').decode('hex'),
            '8de40ccadbc14a82f15cb0ad0de95ca3'.decode('hex')
        ]
        self.assertEqual(rsp[0], expected[0])
        self.assertEqual(rsp[1], expected[1])
        self.assertEqual(rsp[2], expected[2])
