
from base import ServerModuleTest

from twisted.trial.unittest import TestCase
from pyrad import packet

import duoauthproxy.modules.radius_server_concat
import duoauthproxy.modules.radius_server_challenge
import duoauthproxy.modules.mock_client

from duoauthproxy.lib.base import AuthResult
from twisted.internet import defer

from duoauthproxy.lib import duo_async

import mox
import six


class Module(duoauthproxy.modules.mock_client.Module):
    """zope.interface can bite me, too"""

    def __provides__(self, *args, **kwargs):
        pass


class PassThroughPrimaryAtorTestCases(ServerModuleTest, TestCase):
    def setUp(self):
        self.factor = 'phone9'
        super(PassThroughPrimaryAtorTestCases, self).setUp(
            {'pass_through_attr_names': 'Login-LAT-Node,NAS-Identifier'},
            duoauthproxy.modules.radius_server_concat,
            'radius_server_concat',
        )
        self.instance.protocol.primary_ator = self.mox.CreateMock(Module)
        server = self.instance.protocol
        self.concat_password = server.delim.join((self.password, self.factor))

    def tearDown(self):
        super(PassThroughPrimaryAtorTestCases, self).tearDown()

    def enqueue_auth_result(self, pass_through_attrs=None, success=True, radius_attrs=None):
        if pass_through_attrs is None:
            pass_through_attrs = {}
        ator = self.instance.protocol.primary_ator
        method_call = ator.authenticate(
            mox.IsA(six.string_types),
            mox.IsA(six.string_types),
            mox.Or(
                mox.IsA(six.string_types),
                mox.IsA(type(None))
            ),
            pass_through_attrs
        )
        result = AuthResult(success, radius_attrs)
        d = defer.Deferred()
        d.callback(result)
        method_call.AndReturn(d)

    @defer.inlineCallbacks
    def test_no_attributes(self):
        self.enqueue_auth_result()
        self.enqueue_duo_preauth(duo_async.API_RESULT_ALLOW)
        yield self._test_auth(packet.AccessAccept,
                              username=self.username,
                              password=self.concat_password)

    @defer.inlineCallbacks
    def test_one_attribute(self):
        attrs = {'Login-LAT-Node': ['cheese']}
        self.enqueue_auth_result(attrs)
        self.enqueue_duo_preauth(duo_async.API_RESULT_ALLOW)
        yield self._test_auth(
            packet.AccessAccept,
            username=self.username,
            password=self.concat_password,
            request_attrs=attrs
        )

    @defer.inlineCallbacks
    def test_one_attribute_many_values(self):
        attrs = {'Login-LAT-Node': ['cheese', 'gromit']}
        self.enqueue_auth_result(attrs)
        self.enqueue_duo_preauth(duo_async.API_RESULT_ALLOW)
        yield self._test_auth(
            packet.AccessAccept,
            username=self.username,
            password=self.concat_password,
            request_attrs=attrs
        )

    @defer.inlineCallbacks
    def test_two_attributes_many_values(self):
        attrs = {'Login-LAT-Node': ['cheese', 'gromit'], 'NAS-Identifier': ['localhost', '127.0.0.1']}
        self.enqueue_auth_result(attrs)
        self.enqueue_duo_preauth(duo_async.API_RESULT_ALLOW)
        yield self._test_auth(
            packet.AccessAccept,
            username=self.username,
            password=self.concat_password,
            request_attrs=attrs
        )


if __name__ == '__main__':
    import unittest
    unittest.main()
